@@ -1,4 +1,4 @@
-import distutils.spawn
+import shutil
 import logging
 from unittest import TestCase, SkipTest
 
@@ -17,11 +17,11 @@ class TestLdap(HvacIntegrationTestCase, TestCase):
     @classmethod
     def setUpClass(cls):
         # The mock LDAP server requires Java runtime
-        if not distutils.spawn.find_executable("java"):
+        if not shutil.which("java"):
             raise SkipTest("The mock LDAP server requires Java runtime")
 
         try:
-            super(TestLdap, cls).setUpClass()
+            super().setUpClass()
             logging.getLogger("ldap_test").setLevel(logging.ERROR)
 
             cls.mock_server_port = utils.get_free_port()
@@ -29,23 +29,23 @@ class TestLdap(HvacIntegrationTestCase, TestCase):
             cls.ldap_server.start()
         except Exception:
             # Ensure that Vault server is taken down if setUpClass fails
-            super(TestLdap, cls).tearDownClass()
+            super().tearDownClass()
             raise
 
     @classmethod
     def tearDownClass(cls):
-        super(TestLdap, cls).tearDownClass()
+        super().tearDownClass()
         cls.ldap_server.stop()
 
     def setUp(self):
-        super(TestLdap, self).setUp()
+        super().setUp()
         if "ldap/" not in self.client.sys.list_auth_methods():
             self.client.sys.enable_auth_method(
                 method_type="ldap", path=self.TEST_LDAP_PATH
             )
 
     def tearDown(self):
-        super(TestLdap, self).tearDown()
+        super().tearDown()
         self.client.sys.disable_auth_method(
             path=self.TEST_LDAP_PATH,
         )
@@ -57,12 +57,12 @@ class TestLdap(HvacIntegrationTestCase, TestCase):
                 "update binddn",
                 dict(
                     url=MockLdapServer.ldap_url,
-                    bind_dn="cn=vault,ou=Users,dc=hvac,dc=network",
+                    binddn="cn=vault,ou=Users,dc=hvac,dc=network",
                 ),
             ),
             (
-                "update upn_domain",
-                dict(url=MockLdapServer.ldap_url, upn_domain="python-hvac.org"),
+                "update upndomain",
+                dict(url=MockLdapServer.ldap_url, upndomain="python-hvac.org"),
             ),
             (
                 "update certificate",
@@ -71,6 +71,55 @@ class TestLdap(HvacIntegrationTestCase, TestCase):
                     certificate=utils.load_config_file("server-cert.pem"),
                 ),
             ),
+            (
+                "client certificate without key",
+                dict(
+                    url=MockLdapServer.ldap_url,
+                    client_tls_cert=utils.load_config_file("client-cert.pem"),
+                ),
+                exceptions.InvalidRequest,
+                "both client_tls_cert and client_tls_key must be set",
+            ),
+            (
+                "client certificate key without certificate",
+                dict(
+                    url=MockLdapServer.ldap_url,
+                    client_tls_key=utils.load_config_file("client-key.pem"),
+                ),
+                exceptions.InvalidRequest,
+                "both client_tls_cert and client_tls_key must be set",
+            ),
+            (
+                "update config with non-defaults",
+                dict(
+                    url=MockLdapServer.ldap_url,
+                    anonymous_group_search=True,
+                    case_sensitive_names=True,
+                    connection_timeout=60,
+                    deny_null_bind=False,
+                    dereference_aliases="always",
+                    discoverdn=True,
+                    groupfilter=r"((memberUid={{.Username}})(member={{.UserDN}}))",
+                    max_page_size=60,
+                    request_timeout=60,
+                    starttls=True,
+                    tls_max_version="tls11",
+                    tls_min_version="tls11",
+                    token_bound_cidrs=["10.0.0.0"],
+                    token_explicit_max_ttl=60,
+                    token_max_ttl=60,
+                    token_no_default_policy=True,
+                    token_num_uses=10,
+                    token_period=10,
+                    token_policies=["foo"],
+                    token_ttl=60,
+                    token_type="service",
+                    upndomain="bar",
+                    userfilter=r"({{.UserAttr}}={{.Username}})",
+                    use_token_groups=True,
+                    username_as_alias=True,
+                ),
+            ),
             (
                 "incorrect tls version",
                 dict(url=MockLdapServer.ldap_url, tls_min_version="cats"),
@@ -82,11 +131,26 @@ class TestLdap(HvacIntegrationTestCase, TestCase):
     def test_configure(self, test_label, parameters, raises=None, exception_message=""):
         parameters.update(
             {
-                "user_dn": MockLdapServer.ldap_users_dn,
-                "group_dn": MockLdapServer.ldap_groups_dn,
+                "userdn": MockLdapServer.ldap_users_dn,
+                "groupdn": MockLdapServer.ldap_groups_dn,
                 "mount_point": self.TEST_LDAP_PATH,
             }
         )
+        expected_parameters = parameters.copy()
+
+        if utils.vault_version_lt("1.9.0"):
+            # userFilter added in Vault 1.9.0, https://raw.githubusercontent.com/hashicorp/vault/main/CHANGELOG.md
+            expected_parameters.pop("userfilter", None)
+
+        if utils.vault_version_lt("1.11.0"):
+            # connection_timeout and max_page_size added in Vault 1.11.0, https://raw.githubusercontent.com/hashicorp/vault/main/CHANGELOG.md
+            expected_parameters.pop("connection_timeout", None)
+            expected_parameters.pop("max_page_size", None)
+
+        if utils.vault_version_lt("1.14.0"):
+            # dereference_aliases added in Vault 1.14.0, https://raw.githubusercontent.com/hashicorp/vault/main/CHANGELOG.md
+            expected_parameters.pop("dereference_aliases", None)
+
         if raises:
             with self.assertRaises(raises) as cm:
                 self.client.auth.ldap.configure(**parameters)
@@ -104,7 +168,7 @@ class TestLdap(HvacIntegrationTestCase, TestCase):
             read_config_response = self.client.auth.ldap.read_configuration(
                 mount_point=self.TEST_LDAP_PATH,
             )
-            for parameter, argument in parameters.items():
+            for parameter, argument in expected_parameters.items():
                 if parameter == "mount_point":
                     continue
                 self.assertIn(
@@ -479,12 +543,12 @@ class TestLdap(HvacIntegrationTestCase, TestCase):
         test_policy_name = "test-ldap-policy"
         self.client.auth.ldap.configure(
             url=self.ldap_server.url,
-            bind_dn=self.ldap_server.ldap_bind_dn,
-            bind_pass=self.ldap_server.ldap_bind_password,
-            user_dn=self.ldap_server.ldap_users_dn,
-            user_attr="uid",
-            group_dn=self.ldap_server.ldap_groups_dn,
-            group_attr="cn",
+            binddn=self.ldap_server.ldap_bind_dn,
+            bindpass=self.ldap_server.ldap_bind_password,
+            userdn=self.ldap_server.ldap_users_dn,
+            userattr="uid",
+            groupdn=self.ldap_server.ldap_groups_dn,
+            groupattr="cn",
             insecure_tls=True,
             mount_point=self.TEST_LDAP_PATH,
         )
