@@ -17,7 +17,7 @@ class TestKvV2(HvacIntegrationTestCase, TestCase):
     DEFAULT_MOUNT_POINT = "kvv2"
 
     def setUp(self):
-        super(TestKvV2, self).setUp()
+        super().setUp()
         self.client.sys.enable_secrets_engine(
             backend_type="kv",
             path=self.DEFAULT_MOUNT_POINT,
@@ -26,7 +26,7 @@ class TestKvV2(HvacIntegrationTestCase, TestCase):
 
         # We occasionally see issues with the newly enabled secrets engine not becoming available in time for our test cases.
         # So we wait for it to show up in the mounted secrets engines list here before proceeding.
-        path = "{mount_point}/".format(mount_point=self.DEFAULT_MOUNT_POINT)
+        path = f"{self.DEFAULT_MOUNT_POINT}/"
         attempts = 0
         while (
             attempts < 25
@@ -42,7 +42,7 @@ class TestKvV2(HvacIntegrationTestCase, TestCase):
 
     def tearDown(self):
         self.client.sys.disable_secrets_engine(path=self.DEFAULT_MOUNT_POINT)
-        super(TestKvV2, self).tearDown()
+        super().tearDown()
 
     @parameterized.expand(
         [
@@ -275,19 +275,31 @@ class TestKvV2(HvacIntegrationTestCase, TestCase):
                 self.assertEqual(first=v, second=read_secret_result["data"]["data"][k])
 
     @parameterized.expand(
-        [
-            ("successful delete one version written", "hvac"),
+        (
+            combo[0],
+            combo[1],
+            combo[2],
+            dict(enumerate(combo)).get(3, None),
+            raise_on_del,
+            recoverable,
+        )
+        for combo in [
+            ("successful delete one version written", "hvac", 1),
             ("successful delete two versions written", "hvac", 2),
             ("successful delete three versions written", "hvac", 3),
             ("nonexistent path", "no-secret-here", 0, exceptions.InvalidPath),
         ]
+        for raise_on_del in [True, False]
+        for recoverable in [True, False]
     )
     def test_delete_latest_version_of_secret(
         self,
         test_label,
         path,
-        write_secret_before_test=1,
+        write_secret_before_test,
         raises=None,
+        raise_on_del=False,
+        recoverable=None,
         exception_message="",
     ):
         if write_secret_before_test:
@@ -346,6 +358,39 @@ class TestKvV2(HvacIntegrationTestCase, TestCase):
                     second="",
                 )
 
+            should_raise = raise_on_del or not recoverable
+
+            try:
+                read_secret_version_result = (
+                    self.client.secrets.kv.v2.read_secret_version(
+                        path=path,
+                        mount_point=self.DEFAULT_MOUNT_POINT,
+                        raise_on_deleted_version=raise_on_del,
+                    )
+                )
+            except exceptions.InvalidPath:
+                if not should_raise:
+                    raise
+            else:
+                logging.debug(
+                    "read_secret_version_result: %s" % read_secret_version_result
+                )
+                self.assertEqual(
+                    first=read_secret_version_result["data"]["data"],
+                    second=None,
+                )
+                self.assertNotEqual(
+                    first=read_secret_version_result["data"]["metadata"][
+                        "deletion_time"
+                    ],
+                    second="",
+                )
+                self.assertEqual(
+                    first=read_secret_version_result["data"]["metadata"]["version"],
+                    second=write_secret_before_test,
+                    msg=repr(read_secret_version_result),
+                )
+
     @parameterized.expand(
         [
             ("successful delete one version written", "hvac", 1, [1]),
@@ -645,7 +690,7 @@ class TestKvV2(HvacIntegrationTestCase, TestCase):
         test_label,
         path,
         write_secret_before_test=1,
-        destoryed_versions=None,
+        destroyed_versions=None,
         raises=None,
         exception_message="",
     ):
@@ -663,7 +708,7 @@ class TestKvV2(HvacIntegrationTestCase, TestCase):
             with self.assertRaises(raises) as cm:
                 self.client.secrets.kv.v2.destroy_secret_versions(
                     path=path,
-                    versions=destoryed_versions,
+                    versions=destroyed_versions,
                     mount_point=self.DEFAULT_MOUNT_POINT,
                 )
             self.assertIn(
@@ -674,7 +719,7 @@ class TestKvV2(HvacIntegrationTestCase, TestCase):
             destroy_secret_versions_result = (
                 self.client.secrets.kv.v2.destroy_secret_versions(
                     path=path,
-                    versions=destoryed_versions,
+                    versions=destroyed_versions,
                     mount_point=self.DEFAULT_MOUNT_POINT,
                 )
             )
@@ -690,29 +735,29 @@ class TestKvV2(HvacIntegrationTestCase, TestCase):
             logging.debug(
                 "read_secret_metadata_result: %s" % read_secret_metadata_result
             )
-            for destoryed_version in destoryed_versions:
+            for destroyed_version in destroyed_versions:
                 if (
-                    str(destoryed_version)
+                    str(destroyed_version)
                     in read_secret_metadata_result["data"]["versions"]
                 ):
                     self.assertTrue(
                         expr=read_secret_metadata_result["data"]["versions"][
-                            str(destoryed_version)
+                            str(destroyed_version)
                         ]["destroyed"],
-                        msg='Version "{num}" should be destoryed but is not. Full read metadata response versions: {metadata}'.format(
-                            num=destoryed_version,
+                        msg='Version "{num}" should be destroyed but is not. Full read metadata response versions: {metadata}'.format(
+                            num=destroyed_version,
                             metadata=read_secret_metadata_result["data"]["versions"],
                         ),
                     )
-            for nondestoryed_version in set(
+            for nondestroyed_version in set(
                 range(1, write_secret_before_test + 1)
-            ) - set(destoryed_versions):
+            ) - set(destroyed_versions):
                 self.assertFalse(
                     expr=read_secret_metadata_result["data"]["versions"][
-                        str(nondestoryed_version)
+                        str(nondestroyed_version)
                     ]["destroyed"],
-                    msg='Version "{num}" should not be destoryed but is. Full read metadata response versions: {metadata}'.format(
-                        num=nondestoryed_version,
+                    msg='Version "{num}" should not be destroyed but is. Full read metadata response versions: {metadata}'.format(
+                        num=nondestroyed_version,
                         metadata=read_secret_metadata_result["data"]["versions"],
                     ),
                 )
@@ -778,10 +823,23 @@ class TestKvV2(HvacIntegrationTestCase, TestCase):
                 None,
                 "cats",
                 "0s",
+                None,
                 True,
                 exceptions.ParamValidationError,
                 "bool expected for cas_required param",
             ),
+            ("update custom_medata", "hvac", None, None, "0s", dict(color="blue")),
+            (
+                "update with invalid custom_metadata param",
+                "hvac",
+                None,
+                None,
+                "0s",
+                "not-a-dict",
+                True,
+                exceptions.ParamValidationError,
+                "dict expected for custom_metadata param",
+            ),
             ("update with delete_version_after set", "hvac", None, True, "30s"),
         ]
     )
@@ -792,10 +850,14 @@ class TestKvV2(HvacIntegrationTestCase, TestCase):
         max_versions=None,
         cas_required=None,
         delete_version_after="0s",
+        custom_metadata=None,
         write_secret_before_test=True,
         raises=None,
         exception_message="",
     ):
+        if test_label == "update custom_medata" and utils.vault_version_lt("1.9.0"):
+            self.skipTest("custom_metadata support added in Vault 1.9.0")
+
         if write_secret_before_test:
             test_secret = {
                 "pssst": "hi itsame hvac",
@@ -809,6 +871,7 @@ class TestKvV2(HvacIntegrationTestCase, TestCase):
                     path=path,
                     max_versions=max_versions,
                     cas_required=cas_required,
+                    custom_metadata=custom_metadata,
                     delete_version_after=delete_version_after,
                     mount_point=self.DEFAULT_MOUNT_POINT,
                 )
@@ -821,6 +884,7 @@ class TestKvV2(HvacIntegrationTestCase, TestCase):
                 path=path,
                 max_versions=max_versions,
                 cas_required=cas_required,
+                custom_metadata=custom_metadata,
                 delete_version_after=delete_version_after,
                 mount_point=self.DEFAULT_MOUNT_POINT,
             )
@@ -837,6 +901,7 @@ class TestKvV2(HvacIntegrationTestCase, TestCase):
             for key, argument in dict(
                 max_versions=max_versions,
                 cas_required=cas_required,
+                custom_metadata=custom_metadata,
                 delete_version_after=delete_version_after,
             ).items():
                 if argument is not None:
