@@ -1,8 +1,9 @@
 import logging
-from unittest import TestCase
+from unittest import TestCase, skipIf
 
-from parameterized import parameterized, param
+from parameterized import param, parameterized
 
+from hvac import exceptions
 from tests import utils
 from tests.utils.hvac_integration_test_case import HvacIntegrationTestCase
 
@@ -12,7 +13,7 @@ class TestPki(HvacIntegrationTestCase, TestCase):
     TEST_ROLE = "role-test"
 
     def setUp(self):
-        super(TestPki, self).setUp()
+        super().setUp()
         self.client.sys.enable_secrets_engine(
             backend_type="pki",
             path=self.TEST_MOUNT_POINT,
@@ -37,7 +38,7 @@ class TestPki(HvacIntegrationTestCase, TestCase):
 
     def tearDown(self):
         self.client.sys.disable_secrets_engine(path=self.TEST_MOUNT_POINT)
-        super(TestPki, self).tearDown()
+        super().tearDown()
 
     # Read CA Certificate
     @parameterized.expand(
@@ -435,7 +436,7 @@ class TestPki(HvacIntegrationTestCase, TestCase):
         ]
     )
     def test_create_or_update_role(self, label, raises=False, exception_message=""):
-        name = "{}-2".format(self.TEST_ROLE)
+        name = f"{self.TEST_ROLE}-2"
         create_or_update_role_response = self.client.secrets.pki.create_or_update_role(
             name=name,
             mount_point=self.TEST_MOUNT_POINT,
@@ -494,7 +495,7 @@ class TestPki(HvacIntegrationTestCase, TestCase):
         ]
     )
     def test_delete_role(self, label, raises=False, exception_message=""):
-        name = "{}-2".format(self.TEST_ROLE)
+        name = f"{self.TEST_ROLE}-2"
         self.client.secrets.pki.create_or_update_role(
             name=name,
             mount_point=self.TEST_MOUNT_POINT,
@@ -519,7 +520,7 @@ class TestPki(HvacIntegrationTestCase, TestCase):
         ]
     )
     def test_generate_root(self, label, raises=False, exception_message=""):
-        ca_pki_mount_point = "{}-test-ca".format(self.TEST_MOUNT_POINT)
+        ca_pki_mount_point = f"{self.TEST_MOUNT_POINT}-test-ca"
         self.client.sys.enable_secrets_engine(
             backend_type="pki",
             path=ca_pki_mount_point,
@@ -547,7 +548,7 @@ class TestPki(HvacIntegrationTestCase, TestCase):
         ]
     )
     def test_delete_root(self, label, raises=False, exception_message=""):
-        ca_pki_mount_point = "{}-test-ca".format(self.TEST_MOUNT_POINT)
+        ca_pki_mount_point = f"{self.TEST_MOUNT_POINT}-test-ca"
         self.client.sys.enable_secrets_engine(
             backend_type="pki",
             path=ca_pki_mount_point,
@@ -699,3 +700,123 @@ class TestPki(HvacIntegrationTestCase, TestCase):
             first=bool(tidy_response),
             second=True,
         )
+
+    # Read issuer
+    @skipIf(utils.vault_version_lt("1.11.0"), reason="Support added in version 1.11.0.")
+    def test_read_issuer(self):
+        pki_list_response = self.client.secrets.pki.list_issuers(
+            mount_point=self.TEST_MOUNT_POINT
+        )
+
+        logging.debug("pki_list_response: %s" % pki_list_response)
+
+        self.assertIn(
+            member="issuer_name",
+            container=self.client.secrets.pki.read_issuer(
+                issuer_ref=pki_list_response["data"]["keys"][0],
+                mount_point=self.TEST_MOUNT_POINT,
+            )["data"].keys(),
+        )
+
+    # List issuer
+    @skipIf(utils.vault_version_lt("1.11.0"), reason="Support added in version 1.11.0.")
+    def test_list_issuers(self):
+        pki_list_response = self.client.secrets.pki.list_issuers(
+            mount_point=self.TEST_MOUNT_POINT
+        )
+
+        logging.debug("pki_list_response: %s" % pki_list_response)
+
+        self.assertIn("keys", pki_list_response["data"].keys())
+
+    # Update issuer
+    @skipIf(utils.vault_version_lt("1.11.0"), reason="Support added in version 1.11.0.")
+    def test_update_issuer(self):
+        pki_list_response = self.client.secrets.pki.list_issuers(
+            mount_point=self.TEST_MOUNT_POINT
+        )
+
+        logging.debug("pki_list_response: %s" % pki_list_response)
+
+        new_name = "new_issuer_name"
+
+        self.client.secrets.pki.update_issuer(
+            issuer_ref=pki_list_response["data"]["keys"][0],
+            mount_point=self.TEST_MOUNT_POINT,
+            extra_params={"issuer_name": new_name},
+        )
+
+        self.assertEqual(
+            first=self.client.secrets.pki.read_issuer(
+                issuer_ref=pki_list_response["data"]["keys"][0],
+                mount_point=self.TEST_MOUNT_POINT,
+            )["data"]["issuer_name"],
+            second=new_name,
+        )
+
+    # Update issuer - no extra params
+    @skipIf(utils.vault_version_lt("1.11.0"), reason="Support added in version 1.11.0.")
+    def test_update_issuer_no_extra_param(self):
+        pki_list_response = self.client.secrets.pki.list_issuers(
+            mount_point=self.TEST_MOUNT_POINT
+        )
+
+        logging.debug("pki_list_response: %s" % pki_list_response)
+
+        # Read current state of issuer to make sure nothing changes
+        pki_read_response = self.client.secrets.pki.read_issuer(
+            issuer_ref=pki_list_response["data"]["keys"][0],
+            mount_point=self.TEST_MOUNT_POINT,
+        )
+
+        pki_update_response = self.client.secrets.pki.update_issuer(
+            issuer_ref=pki_list_response["data"]["keys"][0],
+            mount_point=self.TEST_MOUNT_POINT,
+        )
+
+        self.assertCountEqual(
+            first=pki_update_response["data"]["usage"].split(","),
+            second=pki_read_response["data"]["usage"].split(","),
+        )
+
+    # Revoke issuer
+    @skipIf(utils.vault_version_lt("1.12.0"), reason="Support added in version 1.12.0.")
+    def test_revoke_issuer(self):
+        pki_list_response = self.client.secrets.pki.list_issuers(
+            mount_point=self.TEST_MOUNT_POINT
+        )
+
+        logging.debug("pki_list_response: %s" % pki_list_response)
+
+        self.client.secrets.pki.revoke_issuer(
+            issuer_ref=pki_list_response["data"]["keys"][0],
+            mount_point=self.TEST_MOUNT_POINT,
+        )
+
+        self.assertEqual(
+            first=self.client.secrets.pki.read_issuer(
+                issuer_ref=pki_list_response["data"]["keys"][0],
+                mount_point=self.TEST_MOUNT_POINT,
+            )["data"]["revoked"],
+            second=True,
+        )
+
+    # Revoke issuer
+    @skipIf(utils.vault_version_lt("1.11.0"), reason="Support added in version 1.11.0.")
+    def test_delete_issuer(self):
+        pki_list_response = self.client.secrets.pki.list_issuers(
+            mount_point=self.TEST_MOUNT_POINT
+        )
+
+        logging.debug("pki_list_response: %s" % pki_list_response)
+
+        self.client.secrets.pki.delete_issuer(
+            issuer_ref=pki_list_response["data"]["keys"][0],
+            mount_point=self.TEST_MOUNT_POINT,
+        )
+
+        with self.assertRaises(exceptions.InternalServerError):
+            self.client.secrets.pki.read_issuer(
+                issuer_ref=pki_list_response["data"]["keys"][0],
+                mount_point=self.TEST_MOUNT_POINT,
+            )
