@@ -12,7 +12,7 @@ class TestSystemBackend(HvacIntegrationTestCase, TestCase):
     TEST_KVV1_MOUNT_POINT = "kvv1_mount"
 
     def setUp(self):
-        super(TestSystemBackend, self).setUp()
+        super().setUp()
         if (
             "%s/" % self.TEST_KVV1_MOUNT_POINT
             not in self.client.sys.list_mounted_secrets_engines()["data"]
@@ -26,7 +26,7 @@ class TestSystemBackend(HvacIntegrationTestCase, TestCase):
     def tearDown(self):
         self.client.token = self.manager.root_token
         self.client.sys.disable_secrets_engine(path=self.TEST_KVV1_MOUNT_POINT)
-        super(TestSystemBackend, self).tearDown()
+        super().tearDown()
 
     def test_unseal_multi(self):
         cls = type(self)
@@ -70,7 +70,7 @@ class TestSystemBackend(HvacIntegrationTestCase, TestCase):
             self.client.sys.enable_auth_method("approle")
 
         self.client.write("auth/approle/role/testrole")
-        result = self.client.write(
+        result = self.client.write_data(
             "auth/approle/role/testrole/secret-id", wrap_ttl="10s"
         )
         self.assertIn("token", result["wrap_info"])
@@ -327,6 +327,7 @@ class TestSystemBackend(HvacIntegrationTestCase, TestCase):
         new_root_token = utils.decode_generated_root_token(
             encoded_token=last_generate_root_response["encoded_root_token"],
             otp=test_otp,
+            url=self.client.url,
         )
         logging.debug("new_root_token: %s" % new_root_token)
         token_lookup_resp = self.client.auth.token.lookup(token=new_root_token)
@@ -357,7 +358,7 @@ class TestSystemBackend(HvacIntegrationTestCase, TestCase):
         test_mount_point = "tune-approle"
         test_description = "this is a test auth backend"
         test_max_lease_ttl = 12345678
-        if "{0}/".format(test_mount_point) in self.client.sys.list_auth_methods():
+        if f"{test_mount_point}/" in self.client.sys.list_auth_methods():
             self.client.sys.disable_auth_method(test_mount_point)
         self.client.sys.enable_auth_method(method_type="approle", path=test_mount_point)
 
@@ -383,9 +384,9 @@ class TestSystemBackend(HvacIntegrationTestCase, TestCase):
     def test_read_lease(self):
         # Set up a test pki backend and issue a cert against some role so we.
         utils.configure_pki(client=self.client)
-        pki_issue_response = self.client.write(
+        pki_issue_response = self.client.write_data(
             path="pki/issue/my-role",
-            common_name="test.hvac.com",
+            data=dict(common_name="test.hvac.com"),
         )
 
         # Read the lease of our test cert that was just issued.
