@@ -15,7 +15,7 @@ def create_app(config=None):
     if "WEBSITE_CONF" in os.environ:
         app.config.from_envvar("WEBSITE_CONF")
 
-    # load app sepcified configuration
+    # load app specified configuration
     if config is not None:
         if isinstance(config, dict):
             app.config.update(config)
@@ -27,11 +27,11 @@ def create_app(config=None):
 
 
 def setup_app(app):
+    db.init_app(app)
+
     # Create tables if they do not exist already
-    @app.before_first_request
-    def create_tables():
+    with app.app_context():
         db.create_all()
 
-    db.init_app(app)
     config_oauth(app)
     app.register_blueprint(bp, url_prefix="")
